# [MedlinePlus](https://medlineplus.gov/)
> MedlinePlus is a service of the National Library of Medicine (NLM), the world's largest medical library, which is part of the National Institutes of Health (NIH).


## MedlinePlus is the New Home of *Genetics Home Reference*
> **Genetics Home Reference** is now part of **MedlinePlus**, an online health information resource from the National Library of Medicine (NLM).
> Information from the Genetics Home Reference website is available in a new section called ***MedlinePlus Genetics***.
